==> zio-aws-mediapackage_2.13-5.17.112.1-sources.jar: zio/aws/mediapackage/model/DescribeHarvestJobRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeHarvestJobRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest = {
    import DescribeHarvestJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeHarvestJobRequest.wrap(buildAwsValue())
}
object DescribeHarvestJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeHarvestJobRequest =
      zio.aws.mediapackage.model.DescribeHarvestJobRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ) extends zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly {
    override val id: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ): zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_2.13-5.17.224.3-sources.jar: zio/aws/mediapackage/model/DescribeHarvestJobRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeHarvestJobRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest = {
    import DescribeHarvestJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeHarvestJobRequest.wrap(buildAwsValue())
}
object DescribeHarvestJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeHarvestJobRequest =
      zio.aws.mediapackage.model.DescribeHarvestJobRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ) extends zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeHarvestJobRequest
  ): zio.aws.mediapackage.model.DescribeHarvestJobRequest.ReadOnly =
    new Wrapper(impl)
}
